from umsc.umsc import UgMultiScriptConverter
import pytest

test_data = [
    ('қол', 'ⱪol'),
    ('баш', 'bax'),
    ('пут', 'put'),
    ('көз', 'køz'),
    ('җәңчи', 'jəngqi'),
    ('сан', 'san'),
    ('сәй', 'səy'),
    ('шир', 'xir'),
    ('китаб', 'kitab'),
    ('вәтән', 'wətən'),
    ('томур', 'tomur'),
    ('көмүр', 'kømür'),
    ('еликтир', 'eliktir'),
    ('шинҗаң', 'xinjang'),
    ('анар', 'anar'),
    ('әнҗүр', 'ənjür'),
    ('орда', 'orda'),
    ('уруш', 'urux'),
    ('өрдәк', 'ørdək'),
    ('үзүм', 'üzüm'),
    ('елан', 'elan'),
    ('инкас', 'inkas'),
    ('нәмәнган', "nəmən'gan"),
    ('өзхан', 'øzhan'),
    ('пасха', 'pasha'),
    ('байрими', 'bayrimi'),
    ('һинган', "ⱨin'gan"),
    ('чәкләнгән', "qəklən'gən"),
    ('башланғуч', 'baxlanƣuq'),
]

@pytest.mark.parametrize("input,expected", test_data)
def test_UCS2UYS(input, expected):
    converter = UgMultiScriptConverter("UCS", "UYS")
    assert converter(input) == expected



from umsc.umsc import UgMultiScriptConverter
import pytest

test_data = [
    ('qol', 'ⱪol'),
    ('bash', 'bax'),
    ('put', 'put'),
    ('köz', 'køz'),
    ('jengchi', 'jəngqi'),
    ('san', 'san'),
    ('sey', 'səy'),
    ('shir', 'xir'),
    ('kitab', 'kitab'),
    ('weten', 'wətən'),
    ('tomur', 'tomur'),
    ('kömür', 'kømür'),
    ('éliktir', 'eliktir'),
    ('shinjang', 'xinjang'),
    ('anar', 'anar'),
    ('enjür', 'ənjür'),
    ('orda', 'orda'),
    ('urush', 'urux'),
    ('ördek', 'ørdək'),
    ('üzüm', 'üzüm'),
    ('élan', 'elan'),
    ('inkas', 'inkas'),
    ("nemen'gan", "nəmən'gan"),
    ('özxan', 'øzhan'),
    ('pasxa', 'pasha'),
    ('bayrimi', 'bayrimi'),
    ("hin'gan", "ⱨin'gan"),
    ("cheklen'gen", "qəklən'gən"),
    ("bashlan'ghuch", 'baxlanƣuq'),
]

@pytest.mark.parametrize("input,expected", test_data)
def test_ULS2UYS(input, expected):
    converter = UgMultiScriptConverter("ULS", "UYS")
    assert converter(input) == expected



from umsc.umsc import UgMultiScriptConverter
import pytest

test_data = [
    ('ⱪol', 'قول'),
    ('bax', 'باش'),
    ('put', 'پۇت'),
    ('køz', 'كۆز'),
    ('jəngqi', 'جەڭچى'),
    ('san', 'سان'),
    ('səy', 'سەي'),
    ('xir', 'شىر'),
    ('kitab', 'كىتاب'),
    ('wətən', 'ۋەتەن'),
    ('tomur', 'تومۇر'),
    ('kømür', 'كۆمۈر'),
    ('eliktir', 'ئېلىكتىر'),
    ('xinjang', 'شىنجاڭ'),
    ('anar', 'ئانار'),
    ('ənjür', 'ئەنجۈر'),
    ('orda', 'ئوردا'),
    ('urux', 'ئۇرۇش'),
    ('ørdək', 'ئۆردەك'),
    ('üzüm', 'ئۈزۈم'),
    ('elan', 'ئېلان'),
    ('inkas', 'ئىنكاس'),
    ("nəmən'gan", 'نەمەنگان'),
    ('øzhan', 'ئۆزخان'),
    ('pasha', 'پاسخا'),
    ('bayrimi', 'بايرىمى'),
    ("ⱨin'gan", 'ھىنگان'),
    ("qəklən'gən", 'چەكلەنگەن'),
    ('baxlanƣuq', 'باشلانغۇچ'),
]

@pytest.mark.parametrize("input,expected", test_data)
def test_UYS2UAS(input, expected):
    converter = UgMultiScriptConverter("UYS", "UAS")
    assert converter(input) == expected



from umsc.umsc import UgMultiScriptConverter
import pytest

test_data = [
    ('qol', 'qol'),
    ('bash', 'baş'),
    ('put', 'put'),
    ('köz', 'köz'),
    ('jengchi', 'ceñçi'),
    ('san', 'san'),
    ('sey', 'sey'),
    ('shir', 'şir'),
    ('kitab', 'kitab'),
    ('weten', 'veten'),
    ('tomur', 'tomur'),
    ('kömür', 'kömür'),
    ('éliktir', 'éliktir'),
    ('shinjang', 'şincañ'),
    ('anar', 'anar'),
    ('enjür', 'encür'),
    ('orda', 'orda'),
    ('urush', 'uruş'),
    ('ördek', 'ördek'),
    ('üzüm', 'üzüm'),
    ('élan', 'élan'),
    ('inkas', 'inkas'),
    ("nemen'gan", 'nemengan'),
    ('özxan', 'özxan'),
    ('pasxa', 'pasxa'),
    ('bayrimi', 'bayrimi'),
    ("hin'gan", 'hingan'),
    ("cheklen'gen", 'çeklengen'),
    ("bashlan'ghuch", 'başlanğuç'),
]

@pytest.mark.parametrize("input,expected", test_data)
def test_ULS2CTS(input, expected):
    converter = UgMultiScriptConverter("ULS", "CTS")
    assert converter(input) == expected



from umsc.umsc import UgMultiScriptConverter
import pytest

test_data = [
    ('ⱪol', 'қол'),
    ('bax', 'баш'),
    ('put', 'пут'),
    ('køz', 'көз'),
    ('jəngqi', 'җәңчи'),
    ('san', 'сан'),
    ('səy', 'сәй'),
    ('xir', 'шир'),
    ('kitab', 'китаб'),
    ('wətən', 'вәтән'),
    ('tomur', 'томур'),
    ('kømür', 'көмүр'),
    ('eliktir', 'еликтир'),
    ('xinjang', 'шинҗаң'),
    ('anar', 'анар'),
    ('ənjür', 'әнҗүр'),
    ('orda', 'орда'),
    ('urux', 'уруш'),
    ('ørdək', 'өрдәк'),
    ('üzüm', 'үзүм'),
    ('elan', 'елан'),
    ('inkas', 'инкас'),
    ("nəmən'gan", "нәмән'ган"),
    ('øzhan', 'өзхан'),
    ('pasha', 'пасха'),
    ('bayrimi', 'байрими'),
    ("ⱨin'gan", "һин'ган"),
    ("qəklən'gən", "чәклән'гән"),
    ('baxlanƣuq', 'башланғуч'),
]

@pytest.mark.parametrize("input,expected", test_data)
def test_UYS2UCS(input, expected):
    converter = UgMultiScriptConverter("UYS", "UCS")
    assert converter(input) == expected



from umsc.umsc import UgMultiScriptConverter
import pytest

test_data = [
    ('qol', 'qol'),
    ('baş', 'bash'),
    ('put', 'put'),
    ('köz', 'köz'),
    ('ceñçi', 'jengchi'),
    ('san', 'san'),
    ('sey', 'sey'),
    ('şir', 'shir'),
    ('kitab', 'kitab'),
    ('veten', 'weten'),
    ('tomur', 'tomur'),
    ('kömür', 'kömür'),
    ('éliktir', 'éliktir'),
    ('şincañ', 'shinjang'),
    ('anar', 'anar'),
    ('encür', 'enjür'),
    ('orda', 'orda'),
    ('uruş', 'urush'),
    ('ördek', 'ördek'),
    ('üzüm', 'üzüm'),
    ('élan', 'élan'),
    ('inkas', 'inkas'),
    ('nemengan', "nemen'gan"),
    ('özxan', 'özxan'),
    ('pasxa', 'pasxa'),
    ('bayrimi', 'bayrimi'),
    ('hingan', "hin'gan"),
    ('çeklengen', "cheklen'gen"),
    ('başlanğuç', "bashlan'ghuch"),
]

@pytest.mark.parametrize("input,expected", test_data)
def test_CTS2ULS(input, expected):
    converter = UgMultiScriptConverter("CTS", "ULS")
    assert converter(input) == expected



from umsc.umsc import UgMultiScriptConverter
import pytest

test_data = [
    ('қол', 'qol'),
    ('баш', 'baş'),
    ('пут', 'put'),
    ('көз', 'köz'),
    ('җәңчи', 'ceñçi'),
    ('сан', 'san'),
    ('сәй', 'sey'),
    ('шир', 'şir'),
    ('китаб', 'kitab'),
    ('вәтән', 'veten'),
    ('томур', 'tomur'),
    ('көмүр', 'kömür'),
    ('еликтир', 'éliktir'),
    ('шинҗаң', 'şincañ'),
    ('анар', 'anar'),
    ('әнҗүр', 'encür'),
    ('орда', 'orda'),
    ('уруш', 'uruş'),
    ('өрдәк', 'ördek'),
    ('үзүм', 'üzüm'),
    ('елан', 'élan'),
    ('инкас', 'inkas'),
    ('нәмәнган', 'nemengan'),
    ('өзхан', 'özxan'),
    ('пасха', 'pasxa'),
    ('байрими', 'bayrimi'),
    ('һинган', 'hingan'),
    ('чәкләнгән', 'çeklengen'),
    ('башланғуч', 'başlanğuç'),
]

@pytest.mark.parametrize("input,expected", test_data)
def test_UCS2CTS(input, expected):
    converter = UgMultiScriptConverter("UCS", "CTS")
    assert converter(input) == expected



from umsc.umsc import UgMultiScriptConverter
import pytest

test_data = [
    ('ⱪol', 'qol'),
    ('bax', 'baş'),
    ('put', 'put'),
    ('køz', 'köz'),
    ('jəngqi', 'ceñçi'),
    ('san', 'san'),
    ('səy', 'sey'),
    ('xir', 'şir'),
    ('kitab', 'kitab'),
    ('wətən', 'veten'),
    ('tomur', 'tomur'),
    ('kømür', 'kömür'),
    ('eliktir', 'éliktir'),
    ('xinjang', 'şincañ'),
    ('anar', 'anar'),
    ('ənjür', 'encür'),
    ('orda', 'orda'),
    ('urux', 'uruş'),
    ('ørdək', 'ördek'),
    ('üzüm', 'üzüm'),
    ('elan', 'élan'),
    ('inkas', 'inkas'),
    ("nəmən'gan", "nemen'gan"),
    ('øzhan', 'özxan'),
    ('pasha', 'pasxa'),
    ('bayrimi', 'bayrimi'),
    ("ⱨin'gan", "hin'gan"),
    ("qəklən'gən", "çeklen'gen"),
    ('baxlanƣuq', 'başlanğuç'),
]

@pytest.mark.parametrize("input,expected", test_data)
def test_UYS2CTS(input, expected):
    converter = UgMultiScriptConverter("UYS", "CTS")
    assert converter(input) == expected



from umsc.umsc import UgMultiScriptConverter
import pytest

test_data = [
    ('قول', 'ⱪol'),
    ('باش', 'bax'),
    ('پۇت', 'put'),
    ('كۆز', 'køz'),
    ('جەڭچى', 'jəngqi'),
    ('سان', 'san'),
    ('سەي', 'səy'),
    ('شىر', 'xir'),
    ('كىتاب', 'kitab'),
    ('ۋەتەن', 'wətən'),
    ('تومۇر', 'tomur'),
    ('كۆمۈر', 'kømür'),
    ('ئېلىكتىر', 'eliktir'),
    ('شىنجاڭ', 'xinjang'),
    ('ئانار', 'anar'),
    ('ئەنجۈر', 'ənjür'),
    ('ئوردا', 'orda'),
    ('ئۇرۇش', 'urux'),
    ('ئۆردەك', 'ørdək'),
    ('ئۈزۈم', 'üzüm'),
    ('ئېلان', 'elan'),
    ('ئىنكاس', 'inkas'),
    ('نەمەنگان', "nəmən'gan"),
    ('ئۆزخان', 'øzhan'),
    ('پاسخا', 'pasha'),
    ('بايرىمى', 'bayrimi'),
    ('ھىنگان', "ⱨin'gan"),
    ('چەكلەنگەن', "qəklən'gən"),
    ('باشلانغۇچ', 'baxlanƣuq'),
]

@pytest.mark.parametrize("input,expected", test_data)
def test_UAS2UYS(input, expected):
    converter = UgMultiScriptConverter("UAS", "UYS")
    assert converter(input) == expected



from umsc.umsc import UgMultiScriptConverter
import pytest

test_data = [
    ('qol', 'қол'),
    ('bash', 'баш'),
    ('put', 'пут'),
    ('köz', 'көз'),
    ('jengchi', 'җәңчи'),
    ('san', 'сан'),
    ('sey', 'сәй'),
    ('shir', 'шир'),
    ('kitab', 'китаб'),
    ('weten', 'вәтән'),
    ('tomur', 'томур'),
    ('kömür', 'көмүр'),
    ('éliktir', 'еликтир'),
    ('shinjang', 'шинҗаң'),
    ('anar', 'анар'),
    ('enjür', 'әнҗүр'),
    ('orda', 'орда'),
    ('urush', 'уруш'),
    ('ördek', 'өрдәк'),
    ('üzüm', 'үзүм'),
    ('élan', 'елан'),
    ('inkas', 'инкас'),
    ("nemen'gan", 'нәмәнган'),
    ('özxan', 'өзхан'),
    ('pasxa', 'пасха'),
    ('bayrimi', 'байрими'),
    ("hin'gan", 'һинган'),
    ("cheklen'gen", 'чәкләнгән'),
    ("bashlan'ghuch", 'башланғуч'),
]

@pytest.mark.parametrize("input,expected", test_data)
def test_ULS2UCS(input, expected):
    converter = UgMultiScriptConverter("ULS", "UCS")
    assert converter(input) == expected
